﻿/*
 * Copyright (c) 2013 Cem Dervis
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the Software
 * is furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
 * INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE
 * OR OTHER DEALINGS IN THE SOFTWARE.
*/

using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.IO;
using System.Windows.Forms;

namespace ImageToaster
{
    public partial class CropperForm : Form
    {
        #region Fields

        // Selected files.
        private readonly List<string> mFiles;

        // Current image memory stream; needed for Image.Save.
        private MemoryStream mCurrentImgStream;

        #endregion

        #region Initialization

        public CropperForm()
        {
            InitializeComponent();
        }

        public CropperForm(List<string> files)
            : this()
        {
            mFiles = files;
        }

        #endregion

        #region Private Methods

        private void DisposeCurrentImage()
        {
            if (imageResizer.BaseImage != null)
            {
                imageResizer.Dispose();
                imageResizer.BaseImage = null;
            }

            if (mCurrentImgStream != null)
            {
                mCurrentImgStream.Dispose();
                mCurrentImgStream = null;
            }
        }

        private void SetImage(string file)
        {
            lblImgFile.Text = Path.GetFileName(file);

            Image img = ImageLoader.Load(file, out mCurrentImgStream);

            imageResizer.BaseImage = img;
        }

        #endregion

        #region Events

        private void btnOk_Click(object sender, EventArgs e)
        {
            string dstFile = mFiles[0];
            string ext = Path.GetExtension(dstFile).ToLowerInvariant();

            if (!chkOverwrite.Checked)
            {
                string withoutExt = Path.ChangeExtension(dstFile, null);
                dstFile = withoutExt + "_cropped" + ext;
            }

            imageResizer.SaveImage(dstFile);

            mFiles.RemoveAt(0);

            if (mFiles.Count > 0)
            {
                SetImage(mFiles[0]);
            }
            else
            {
                this.DialogResult = DialogResult.OK;
            }
        }

        private void btnSkip_Click(object sender, EventArgs e)
        {
            if (mFiles.Count > 0)
            {
                mFiles.RemoveAt(0);
                DisposeCurrentImage();
            }

            if (mFiles.Count == 0)
                this.DialogResult = DialogResult.OK;
        }

        private void panel_Paint(object sender, PaintEventArgs e)
        {
            var g = e.Graphics;

            var gradBotColor = Color.FromArgb(220, 220, 220);
            var gradTopColor = Color.White;

            using (var brush = new LinearGradientBrush(panel.ClientRectangle, gradTopColor, gradBotColor, 90))
            {
                g.FillRectangle(brush, panel.ClientRectangle);
            }
        }

        private void lblImgFile_Click(object sender, EventArgs e)
        {
            Process.Start(mFiles[0]);
        }

        private void CropperForm_Load(object sender, EventArgs e)
        {
            SetImage(mFiles[0]);
        }

        #endregion
    }
}
