﻿/*
 * Copyright (c) 2013 Cem Dervis
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the Software
 * is furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
 * INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE
 * OR OTHER DEALINGS IN THE SOFTWARE.
*/

using System.Drawing;
using System.IO;

namespace ImageToaster
{
    /// <summary>
    /// Converts images to a specific format.
    /// </summary>
    internal static class ImageConverter
    {
        /// <summary>
        /// Converts all selected images to a specific format.
        /// </summary>
        ///
        /// <param name="toaster">The toaster.</param>
        /// <param name="dstFormat">Destination format.</param>
        internal static void Convert(ImageToasterMenu toaster, ImageType dstFormat)
        {
            // Convert every image.
            foreach (var file in toaster.SelectedItemPaths)
            {
                // Check if conversion is necessary (think about .jpg -> .jpg).
                if (!NeedToConvert(file, dstFormat))
                    continue;

                // Determine the destination file.
                // The destination file is the same as the input file, but with the destination format's extension.
                string folder = Path.GetDirectoryName(file);
                string dstFile = Path.GetFileNameWithoutExtension(file) + ImageFormatHelper.GetExtensionFromType(dstFormat);
                dstFile = Path.Combine(folder, dstFile);

                // Save the image
                MemoryStream str = null;
                Image img = ImageLoader.Load(file, out str);

                img.Save(dstFile, ImageFormatHelper.GetImageFormatFromType(dstFormat));

                img.Dispose();
                str.Dispose();
            }
        }

        private static bool NeedToConvert(string srcFile, ImageType dstFormat)
        {
            string ext = Path.GetExtension(srcFile).ToLowerInvariant();

            ImageType actual = ImageFormatHelper.GetImageTypeFromExtension(ext);

            return (dstFormat != actual);
        }
    }
}
