﻿/*
 * Copyright (c) 2013 Cem Dervis
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the Software
 * is furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
 * INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE
 * OR OTHER DEALINGS IN THE SOFTWARE.
*/

using System;
using System.Drawing.Imaging;

namespace ImageToaster
{
    /// <summary>
    /// An image type.
    /// </summary>
    public enum ImageType
    {
        Jpeg,
        Png,
        Bmp,
        Gif,
        Icon,
        Tiff
    }

    /// <summary>
    /// Image format helper.
    /// </summary>
    internal static class ImageFormatHelper
    {
        internal static bool IsSupported(string extension)
        {
            try
            {
                GetImageFormatFromExtension(extension);
                return true;
            }
            catch (Exception)
            {
                return false;
            }
        }

        internal static ImageFormat GetImageFormatFromExtension(string extension)
        {
            extension = extension.ToLowerInvariant();
            switch (extension)
            {
                case ".jpg":
                case ".jpeg": return GetImageFormatFromType(ImageType.Jpeg);
                case ".png": return GetImageFormatFromType(ImageType.Png);
                case ".bmp": return GetImageFormatFromType(ImageType.Bmp);
                case ".gif": return GetImageFormatFromType(ImageType.Gif);
                case ".ico": return GetImageFormatFromType(ImageType.Icon);
                case ".tif":
                case ".tiff":
                    return GetImageFormatFromType(ImageType.Tiff);
            }

            throw new NotSupportedException(extension);
        }

        internal static ImageFormat GetImageFormatFromType(ImageType type)
        {
            switch (type)
            {
                case ImageType.Jpeg:
                    return ImageFormat.Jpeg;
                case ImageType.Png:
                    return ImageFormat.Png;
                case ImageType.Bmp:
                    return ImageFormat.Bmp;
                case ImageType.Gif:
                    return ImageFormat.Gif;
                case ImageType.Icon:
                    return ImageFormat.Icon;
                case ImageType.Tiff:
                    return ImageFormat.Tiff;
            }

            throw new NotSupportedException(type.ToString());
        }

        internal static string GetExtensionFromType(ImageType type)
        {
            switch (type)
            {
                case ImageType.Jpeg: return ".jpg";
                case ImageType.Png: return ".png";
                case ImageType.Bmp: return ".bmp";
                case ImageType.Gif: return ".gif";
                case ImageType.Icon: return ".ico";
                case ImageType.Tiff: return ".tif";
            }

            throw new NotSupportedException(type.ToString());
        }

        internal static ImageType GetImageTypeFromExtension(string ext)
        {
            switch (ext)
            {
                case ".jpg":
                case ".jpeg":
                    return ImageType.Jpeg;
                case ".png": return ImageType.Png;
                case ".bmp": return ImageType.Bmp;
                case ".gif": return ImageType.Gif;
                case ".ico": return ImageType.Icon;
                case ".tif":
                case ".tiff":
                    return ImageType.Tiff;
            }

            throw new NotSupportedException(ext);
        }
    }
}
