﻿/*
 * Copyright (c) 2013 Cem Dervis
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the Software
 * is furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
 * INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE
 * OR OTHER DEALINGS IN THE SOFTWARE.
*/

using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Runtime.InteropServices;
using System.Windows.Forms;
using SharpShell.Attributes;
using SharpShell.SharpContextMenu;

namespace ImageToaster
{
    [ComVisible(true)]
    [COMServerAssociation(AssociationType.ClassOfExtension, ".jpg", ".jpeg", ".png", ".bmp", ".gif", ".ico", ".tif", ".tiff")]
    public class ImageToasterMenu : SharpContextMenu
    {
        protected override bool CanShowMenu()
        {
            return true;
        }

        protected override ContextMenuStrip CreateMenu()
        {
            var menu = new ContextMenuStrip();

            var mainEntry = new ToolStripMenuItem("ImageToaster", Properties.Resources.toast);

            mainEntry.DropDownItems.Add(CreateConvertMenu());
            mainEntry.DropDownItems.Add(new ToolStripSeparator());
            mainEntry.DropDownItems.Add(CreateResizeMenu());
            mainEntry.DropDownItems.Add(CreateCropMenu());

            menu.Items.Add(mainEntry);

            return menu;
        }

        private ToolStripMenuItem CreateConvertMenu()
        {
            var item = new ToolStripMenuItem(LanguageManager.GetString("Convert"));

            // Add all known image types.
            var imgTypeValues = Enum.GetValues(typeof (ImageType));
            foreach (var imgTypeValue in imgTypeValues)
            {
                item.DropDownItems.Add(imgTypeValue.ToString()).Click +=
                    (sender, args) => ImageConverter.Convert(this, (ImageType) imgTypeValue);
            }

            return item;
        }

        private ToolStripMenuItem CreateResizeMenu()
        {
            var item = new ToolStripMenuItem(LanguageManager.GetString("Resize"));

            item.Click += delegate
                {
                    var files = SelectedItemPaths.Where(
                        file => ImageFormatHelper.IsSupported(Path.GetExtension(file))).ToList();

                    if (files.Count > 0)
                    {
                        using (var form = new ResizerForm(files))
                        {
                            form.ShowDialog();
                        }
                    }
                };

            return item;
        }

        private ToolStripMenuItem CreateCropMenu()
        {
            var item = new ToolStripMenuItem(LanguageManager.GetString("Crop"));

            item.Click += delegate
            {
                var files = SelectedItemPaths.Where(
                    file => ImageFormatHelper.IsSupported(Path.GetExtension(file))).ToList();

                if (files.Count > 0)
                {
                    using (var form = new CropperForm(files))
                    {
                        form.ShowDialog();
                    }
                }
            };

            return item;
        }

    } 
}
